#
# __init__.py
#
# Copyright (C) AB Strakt 2001, All rights reserved
#
# $Id: __init__.py,v 1.4 2004/07/22 12:01:25 martin Exp $
#
"""
pyOpenSSL - A simple wrapper around the OpenSSL library
"""
import rand, crypto, SSL, tsafe
from version import __version__
